@@ -17,6 +17,7 @@ from ..models.datasource import (
     FileDataSourceRequest,
     CodeAnalysisDataSourceRequest,
     CodeExplorationDataSourceRequest,
+    ElasticsearchStatsResponse,
 )
 from ..models.assistant import AssistantListResponse
 from ..utils import ApiRequestHandler
@@ -253,3 +254,22 @@ class DatasourceService:
             dict,
             json_data=request.model_dump(by_alias=True, exclude_none=True),
         )
+
+    def get_elasticsearch_stats(self, datasource_id: str) -> ElasticsearchStatsResponse:
+        """Get Elasticsearch statistics for a specific datasource index.
+
+        Args:
+            datasource_id: ID of the datasource
+
+        Returns:
+            ElasticsearchStatsResponse with Elasticsearch statistics including:
+            - index_name: Name of the index in Elasticsearch
+            - size_in_bytes: Size of the index in bytes
+
+        Raises:
+            ApiError: If the datasource is not found, platform datasources are not supported,
+                     or Elasticsearch statistics are not available.
+        """
+        return self._api.get(
+            f"/v1/index/{datasource_id}/elasticsearch", ElasticsearchStatsResponse
+        )
